OgParser class
Parser for extracting Open Graph metadata from HTML content.
Parses HTML strings to extract Open Graph tags and other meta tags such as title, description, site name, images, and favicons.
Properties
- desc → String?
-
no setter
- favicon → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- html → String
-
final
- image → String?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- siteName → String?
-
no setter
- title → String?
-
no setter
Methods
-
extractMetaContent(
{required String attributeKey, required String attributeValue}) → String? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited